/*
 * resourced
 *
 * Copyright (c) 2000 - 2013 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */


/*
 * @file trace.h
 * Common macros for tracing
 */

#ifndef _SYSTEM_RESOURCE_TRACE_H_
#define _SYSTEM_RESOURCE_TRACE_H_

#include "config.h"
#include "const.h"
#include <dlog.h>
#include <errno.h>
#include <signal.h>
#include <stdio.h>
#include <sys/syslog.h>

#include "macro.h"

#undef LOG_TAG
#define LOG_TAG "RESOURCED"

enum log_type {
	LOG_TYPE_STANDARD = 0,
	LOG_TYPE_FILE,
	LOG_TYPE_DLOG,
	LOG_TYPE_MAX
};

extern enum log_type logtype;

#define _E(fmt, arg...) do {			\
		LOGE(fmt, ##arg);		\
} while (0)

#define _W(fmt, arg...) do { \
		LOGW(fmt, ##arg); \
} while (0)

#define _D(fmt, arg...) do {				\
		LOGD(fmt, ##arg);			\
} while (0)

#define _I(fmt, arg...) do {				\
		LOGI(fmt, ##arg);			\
} while (0)

#define _SE(fmt, arg...) SECURE_LOGE(fmt, ##arg)
#define _SW(fmt, arg...) SECURE_LOGW(fmt, ##arg)
#define _SD(fmt, arg...) SECURE_LOGD(fmt, ##arg)
#define _SI(fmt, arg...) SECURE_LOGI(fmt, ##arg)

#define TRACE_RET_ERRCODE(type, error_code)			\
do {								\
	_##type("errno %d, errmsg %m", error_code); \
} while (0)

#define TRACE_RET_ERRCODE_MSG(type, error_code, fmt, arg...)	\
do {								\
	_##type(fmt, ##arg);					\
	_##type("errno %d, errmsg %m", error_code); \
} while (0)

#define ETRACE_ERRNO() TRACE_RET_ERRCODE(E, -errno)

#define ETRACE_ERRNO_MSG(fmt, arg...) \
	TRACE_RET_ERRCODE_MSG(E, -errno, fmt, ##arg)

#define LOG_DUMP(fp, fmt, arg...) \
	if (fp) fprintf(fp, fmt, ##arg); \
	else _E(fmt, ##arg);

#endif	/* _SYSTEM_RESOURCE_TRACE_H_ */
