/*
 * resourced
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * @file heart-dbus.c
 *
 * @desc dbus methods for heart module
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <glib.h>
#include <gio/gio.h>

#include "dbus-handler.h"
#include "heart.h"
#include "logging.h"
#include "macro.h"
#include "notifier.h"
#include "trace.h"

#define MAX_XML_LEN 16384

static void dbus_update_data_list(GDBusMethodInvocation *invocation, GVariant *params)
{
	resourced_notify(RESOURCED_NOTIFIER_DATA_UPDATE, NULL);

	logging_save_to_storage(true);
	/* update data list from db */
	logging_update(true);

	D_BUS_REPLY_NULL(invocation);
}

static void dbus_flush_cache(GDBusMethodInvocation *invocation, GVariant *params)
{
	/* flush module cache */
	logging_save_to_storage(true);

	D_BUS_REPLY_NULL(invocation);
}

static const char dbus_methods_xml_prefix[] =
"<node>"
"	<interface name='"RESOURCED_INTERFACE_LOGGING"'>"
"		<method name='UpdateDataList'>"
"		</method>"
"		<method name='Flush'>"
"		</method>";

static const char dbus_methods_xml_suffix[] =
"	</interface>"
"</node>";

static int num_methods = 2;
static char dbus_methods_xml_body[MAX_XML_LEN];
static struct d_bus_method dbus_methods[128] = {
	{ "UpdateDataList", dbus_update_data_list },
	{ "Flush",          dbus_flush_cache },
};

void heart_dbus_declare_methods(const char *xml, const struct d_bus_method *methods,
								const size_t size)
{
	int i;

	g_strlcat(dbus_methods_xml_body, xml, MAX_XML_LEN);

	for (i = 0; i < size; i++)
		dbus_methods[num_methods++] = methods[i];
}

int heart_dbus_init(void)
{
	char dbus_methods_xml[MAX_XML_LEN] = { 0, };

	g_strlcat(dbus_methods_xml, dbus_methods_xml_prefix, MAX_XML_LEN);
	g_strlcat(dbus_methods_xml, dbus_methods_xml_body, MAX_XML_LEN);
	g_strlcat(dbus_methods_xml, dbus_methods_xml_suffix, MAX_XML_LEN);

	return d_bus_register_methods(RESOURCED_PATH_LOGGING, dbus_methods_xml,
			dbus_methods, num_methods);
}
