/*
 * resourced
 *
 * Copyright (c) 2012 - 2013 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * @file lowmem_dbus.c
 *
 * @desc lowmem dbus for oom triger
 *
 * Copyright (c) 2013 Samsung Electronics Co., Ltd. All rights reserved.
 *
 */

#include "trace.h"
#include "lowmem-handler.h"
#include "dbus-handler.h"
#include "resourced.h"
#include "macro.h"
#include "memory-common.h"
#include "procfs.h"
#include "util.h"

static void lowmem_dbus_oom_set_threshold(GVariant *params)
{
	int level = -1, thres = -1;
	const char *const gtype = "(ii)";

	ret_if_gvariant_type_mismatch(params, gtype);
	g_variant_get(params, gtype, &level, &thres);
	ret_unless(level >= 0);
	ret_unless(thres >= 0);

	lowmem_memcg_set_threshold(MEMCG_MEMORY, level, thres);
}

static void lowmem_dbus_oom_set_leave_threshold(GVariant *params)
{
	int thres = -1;
	const char *const gtype = "(i)";

	ret_if_gvariant_type_mismatch(params, gtype);
	g_variant_get(params, gtype, &thres);
	ret_unless(thres >= 0);

	lowmem_memcg_set_leave_threshold(MEMCG_MEMORY, thres);
}

static void lowmem_dbus_oom_trigger(GVariant *params)
{
	lowmem_trigger_reclaim(OOM_NOMEMORY_CHECK,
				MAX_MEMORY_CGROUP_VICTIMS, LMK_OLDEST, 0);
}

static void lowmem_dbus_set_perceptible(GVariant *params)
{
	pid_t pid = 0;
	const char *const gtype = "(i)";

	ret_if_gvariant_type_mismatch(params, gtype);
	g_variant_get(params, gtype, &pid);
	ret_unless(pid > 0);

	proc_set_oom_score_adj(pid, OOMADJ_BACKGRD_PERCEPTIBLE);
}

static void lowmem_dbus_set_platform(GVariant *params)
{
	pid_t pid = 0;
	const char *const gtype = "(i)";

	ret_if_gvariant_type_mismatch(params, gtype);
	g_variant_get(params, gtype, &pid);
	ret_unless(pid > 0);

	lowmem_trigger_swap(pid, MEMCG_SWAP);
}

static void lowmem_dbus_set_memlimit(GVariant *params)
{
	pid_t pid = 0;
	unsigned int limit = 0;
	const char *const gtype = "(iu)";

	ret_if_gvariant_type_mismatch(params, gtype);
	g_variant_get(params, gtype, &pid, &limit);
	ret_unless(pid > 0);
	ret_unless(limit > 0);

	lowmem_limit_set(pid, limit);
}

static const struct d_bus_signal dbus_signals[] = {
	/* RESOURCED DBUS */
	{RESOURCED_PATH_OOM, RESOURCED_INTERFACE_OOM,
	    SIGNAL_OOM_SET_THRESHOLD, lowmem_dbus_oom_set_threshold, NULL},
	{RESOURCED_PATH_OOM, RESOURCED_INTERFACE_OOM,
	    SIGNAL_OOM_SET_LEAVE_THRESHOLD,
	    lowmem_dbus_oom_set_leave_threshold, NULL},
	{RESOURCED_PATH_OOM, RESOURCED_INTERFACE_OOM,
	    SIGNAL_OOM_TRIGGER, lowmem_dbus_oom_trigger, NULL},
	{RESOURCED_PATH_OOM, RESOURCED_INTERFACE_OOM,
	    SIGNAL_OOM_SET_PERCEPTIBLE, lowmem_dbus_set_perceptible, NULL},
	{RESOURCED_PATH_OOM, RESOURCED_INTERFACE_OOM,
	    SIGNAL_OOM_SET_PLATFORM, lowmem_dbus_set_platform, NULL},
	{RESOURCED_PATH_OOM, RESOURCED_INTERFACE_OOM,
	    SIGNAL_OOM_SET_MEMLIMIT, lowmem_dbus_set_memlimit, NULL},
};

void lowmem_dbus_init(void)
{
	d_bus_register_signals(dbus_signals, ARRAY_SIZE(dbus_signals));
}
